<?php

namespace Roots\Sage\Setup;

use Roots\Sage\Assets;

/**
 * Theme setup
 */
function setup() {
  // Enable features from Soil when plugin is activated
  // https://roots.io/plugins/soil/
  add_theme_support('soil-clean-up');
  add_theme_support('soil-nav-walker');
  add_theme_support('soil-nice-search');
  //add_theme_support('soil-jquery-cdn');
  //add_theme_support('soil-relative-urls');

  // Make theme available for translation
  // Community translations can be found at https://github.com/roots/sage-translations
  load_theme_textdomain('sage', get_template_directory() . '/lang');

  // Enable plugins to manage the document title
  // http://codex.wordpress.org/Function_Reference/add_theme_support#Title_Tag
  add_theme_support('title-tag');

  // Register wp_nav_menu() menus
  // http://codex.wordpress.org/Function_Reference/register_nav_menus

  // Enable post thumbnails
  // http://codex.wordpress.org/Post_Thumbnails
  // http://codex.wordpress.org/Function_Reference/set_post_thumbnail_size
  // http://codex.wordpress.org/Function_Reference/add_image_size
    add_theme_support( 'post-thumbnails' );
    add_image_size( 'mosaic', 1000, 1000, true );
    add_image_size( 'full_viewport', 1920, '', false );
    add_image_size( 'flex_50', 600, '', false );
    add_image_size( 'flex_100', 1200, '', false );
    add_image_size( 'flex_33', 400, '', false );
    add_image_size( 'flex_25', 300, '', false );
    add_image_size( 'square', 600, 600, true );


  // Enable post formats
  // http://codex.wordpress.org/Post_Formats
  //add_theme_support('post-formats', ['aside', 'gallery', 'link', 'image', 'quote', 'video', 'audio']);

  // Enable HTML5 markup support
  // http://codex.wordpress.org/Function_Reference/add_theme_support#HTML5
  add_theme_support('html5', ['caption', 'comment-form', 'comment-list', 'search-form']);

  // Use main stylesheet for visual editor
  // To add custom styles edit /assets/styles/layouts/_tinymce.scss
  // add_editor_style(Assets\asset_path('styles/main.css'));

  // Add new nav

  // Register wp_nav_menu() menus
  // http://codex.wordpress.org/Function_Reference/register_nav_menus
  register_nav_menus([
   // 'primary_navigation' => __( 'Primary Navigation', 'sage' ),
    'home_navigation' => __( 'Home navigation', 'sage' ),
  //  'partners_navigation' => __( 'Partners navigation', 'sage' ),
   // 'partners_navigation_old' => __( 'Partners navigation_old', 'sage' ),
	//'projects_navigation' => __( 'Projects Navigation', 'sage' ),
	
  ]);

  if( function_exists('acf_add_options_sub_page') ) {
    acf_add_options_sub_page( 'Options' );
  }

}
add_action('after_setup_theme', __NAMESPACE__ . '\\setup');

/**
 * Determine which pages should NOT display the sidebar
 */
function display_sidebar() {
  static $display;

  isset($display) || $display = !in_array(true, [
  ]);

  return apply_filters('sage/display_sidebar', $display);
}

/**
 * Theme assets
 */

function assets() {
  wp_enqueue_style('sage/css', Assets\asset_path('styles/main.css'), false, null);

  if (is_single() && comments_open() && get_option('thread_comments')) {
    wp_enqueue_script('comment-reply');
  }
	if(is_front_page()  ||  !is_page( 'partnership-form' )){
		wp_enqueue_script('sage/js', Assets\asset_path('scripts/main.js'), ['jquery'], null, true);

	}else{
		wp_enqueue_script('sage/js', Assets\asset_path('scripts/main2.js'), ['jquery'], null, true);
	}
  
}
add_action('wp_enqueue_scripts', __NAMESPACE__ . '\\assets', 100);
